@@ -99,18 +99,12 @@ STRUCTURE = Nav(
 						Nav(lazy_gettext("Le Remplacement de cartes")),
 						Nav(lazy_gettext("Le Ramp")),
 						Nav(lazy_gettext("Les Mana dorks")),
-						Nav(lazy_gettext("Les Grosses créatures")),
-					],
-				),
-				Nav(
-					lazy_gettext("Cartes par fonctionnalité"),
-					index=False,
-					children=[
-						Nav(lazy_gettext("Les Piocheurs")),
-						Nav(lazy_gettext("Les Spot Removals")),
-						Nav(lazy_gettext("Les Mass Removals")),
+						Nav(lazy_gettext("Les Grosses Créatures")),
 					],
 				),
+				Nav(lazy_gettext("Les Piocheurs")),
+				Nav(lazy_gettext("Les Spot Removals")),
+				Nav(lazy_gettext("Les Mass Removals")),
 			],
 		),
 	],
